/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'liststyle', 'bn', {
	armenian: 'আর্মেনিয়ান সংখ্যাক্রমে বিন্যাস',
	bulletedTitle: 'Bulleted List Properties',
	circle: 'Circle',
	decimal: 'Decimal (1, 2, 3, etc.)',
	decimalLeadingZero: 'Decimal leading zero (01, 02, 03, etc.)',
	disc: 'Disc',
	georgian: 'Georgian numbering (an, ban, gan, etc.)',
	lowerAlpha: 'Lower Alpha (a, b, c, d, e, etc.)',
	lowerGreek: 'Lower Greek (alpha, beta, gamma, etc.)',
	lowerRoman: 'Lower Roman (i, ii, iii, iv, v, etc.)',
	none: 'None',
	notset: '<not set>',
	numberedTitle: 'Numbered List Properties',
	square: 'Square',
	start: 'Start',
	type: 'Type',
	upperAlpha: 'Upper Alpha (A, B, C, D, E, etc.)',
	upperRoman: 'Upper Roman (I, II, III, IV, V, etc.)',
	validateStartNumber: 'List start number must be a whole number.'
} );
